@@ -51,11 +51,15 @@
 using namespace KDevelop;
 
 K_PLUGIN_FACTORY(PhpDocsFactory, registerPlugin<PhpDocsPlugin>(); )
-K_EXPORT_PLUGIN(PhpDocsFactory(KAboutData("kdevphpdocs","kdevphpdocs", ki18n("PhpDocs"), "1.0.2", ki18n("Check PHP.net documentation"), KAboutData::License_GPL).addAuthor(ki18n("Milian Wolff"), ki18n("Maintainer"), "mail@milianw.de", "http://milianw.de")))
+K_EXPORT_PLUGIN(PhpDocsFactory(KAboutData("kdevphpdocs","kdevphpdocs", ki18n("PhpDocs"),
+                                          "1.0.80", ki18n("Check PHP.net documentation"),
+                               KAboutData::License_GPL).addAuthor(ki18n("Milian Wolff"),
+                               ki18n("Maintainer"), "mail@milianw.de", "http://milianw.de")))
 
 PhpDocsPlugin::PhpDocsPlugin(QObject* parent, const QVariantList& args)
     : IPlugin(PhpDocsFactory::componentData(), parent), m_model(new PhpDocsModel(this))
 {
+    KDEV_USE_EXTENSION_INTERFACE( KDevelop::IDocumentationProvider )
     Q_UNUSED(args);
 
     readConfig();
@@ -195,7 +199,7 @@ KSharedPtr< IDocumentation > PhpDocsPlugin::documentationForIndex(const QModelIn
     ));
 }
 
-void PhpDocsPlugin::loadUrl(const KUrl& url) const
+void PhpDocsPlugin::loadUrl(const QUrl& url) const
 {
     kDebug() << "loading URL" << url;
     KSharedPtr<IDocumentation> doc = documentationForUrl(url, QString());
